@@ -21,6 +21,7 @@ import time
 
 from sushy import exceptions
 from sushy.resources.task_monitor import TaskMonitor
+from sushy import utils
 
 LOG = logging.getLogger(__name__)
 
@@ -87,15 +88,20 @@ class Connector(object):
         url = path if urlparse.urlparse(path).netloc else urlparse.urljoin(
             self._url, path)
         headers = headers or {}
-        if not any(k.lower() == 'odata-version' for k in headers):
+        lc_headers = [k.lower() for k in headers]
+        if data is not None and 'content-type' not in lc_headers:
+            headers['Content-Type'] = 'application/json'
+        if 'odata-version' not in lc_headers:
             headers['OData-Version'] = '4.0'
         # TODO(lucasagomes): We should mask the data to remove sensitive
         # information
         LOG.debug('HTTP request: %(method)s %(url)s; headers: %(headers)s; '
                   'body: %(data)s; blocking: %(blocking)s; timeout: '
                   '%(timeout)s; session arguments: %(session)s;',
-                  {'method': method, 'url': url, 'headers': headers,
-                   'data': data, 'blocking': blocking, 'timeout': timeout,
+                  {'method': method, 'url': url,
+                   'headers': utils.sanitize(headers),
+                   'data': utils.sanitize(data),
+                   'blocking': blocking, 'timeout': timeout,
                    'session': extra_session_req_kwargs})
         try:
             response = self._session.request(method, url, json=data,
